custom_tutorial_overlay library

A customizable tutorial overlay package for Flutter

Classes

StepIndicatorWidget
Widget that displays the current step indicator
TutorialBuilder
Declarative widget for defining tutorials
TutorialConfig
Configuration for the tutorial overlay
TutorialController
Controller for managing tutorial state and navigation
TutorialOverlay
Main tutorial overlay widget
TutorialOverlayPainter
Custom painter for rendering the tutorial overlay with spotlight effect
TutorialScope
Inherited widget that provides the tutorial controller to descendants
TutorialStep
Represents a single step in the tutorial
TutorialTooltip
Widget that displays the tooltip content with navigation controls

Enums

SpotlightShape
Defines the shape of the spotlight
StepIndicatorPosition
Position of the step indicator
StepIndicatorStyle
Style of the step indicator
TooltipPosition
Defines the position of the tooltip relative to the spotlight

Extensions

TutorialExtensions on BuildContext
Extension methods for easier tutorial control

Typedefs

StepCallback = void Function(int stepIndex)
TutorialCallback = void Function()
Callback function types
TutorialStepBuilder = TutorialStep Function(BuildContext context, int index)
Builder function for declarative tutorial steps